==> shellcheck-0.10.0-12-riscv64.pkg.tar.zst: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ShellCheck
version:              0.10.0
visibility:           public
id:                   ShellCheck-0.10.0-BZtbbfpPJHJ3cRA9b1bMWj
key:                  ShellCheck-0.10.0-BZtbbfpPJHJ3cRA9b1bMWj
license:              GPL-3.0-only
maintainer:           vidar@vidarholen.net
author:               Vidar Holen
homepage:             https://www.shellcheck.net/
synopsis:             Shell script analysis tool
description:
    The goals of ShellCheck are:

    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.

    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.

    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.

category:             Static Analysis
abi:                  121830d57b54174bbd0e00494118fb69
exposed:              True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.CFG
    ShellCheck.CFGAnalysis ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ControlFlow
    ShellCheck.Checks.Custom ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Debug ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Prelude
    ShellCheck.Regex

hidden-modules:       Paths_ShellCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ShellCheck-0.10.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ShellCheck-0.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/shellcheck
hs-libraries:         HSShellCheck-0.10.0-BZtbbfpPJHJ3cRA9b1bMWj
depends:
    Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr array-0.5.4.0 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    directory-1.3.6.2 fgl-5.8.2.0-Eb6xdEigYbA8WAuh82pZJA
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.15.0 process-1.6.16.0
    regex-tdfa-1.3.2.2-9KQuOdDpiBL9UBsQEK6k8E transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html:         /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.10.0-62.1-riscv64.pkg.tar.zst: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ShellCheck
version:              0.10.0
visibility:           public
id:                   ShellCheck-0.10.0-IMPJbtSJnDUHvpaetpaQHk
key:                  ShellCheck-0.10.0-IMPJbtSJnDUHvpaetpaQHk
license:              GPL-3.0-only
maintainer:           vidar@vidarholen.net
author:               Vidar Holen
homepage:             https://www.shellcheck.net/
synopsis:             Shell script analysis tool
description:
    The goals of ShellCheck are:

    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.

    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.

    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.

category:             Static Analysis
abi:                  42a796daa271ca7ace4842a125948282
exposed:              True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.CFG
    ShellCheck.CFGAnalysis ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ControlFlow
    ShellCheck.Checks.Custom ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Debug ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Prelude
    ShellCheck.Regex

hidden-modules:       Paths_ShellCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/shellcheck
hs-libraries:         HSShellCheck-0.10.0-IMPJbtSJnDUHvpaetpaQHk
depends:
    Diff-0.4.1-Jc1TR9aaNUv129X0zlHNSG
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 fgl-5.8.3.0-CDsLLgXvJNx6rGJfKCYovw
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1 process-1.6.18.0
    regex-tdfa-1.3.2.4-LXwWfM9riXbAuaKHkk8lra transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html:         /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
